package com.solution.system.mapper;

import java.util.List;
import com.solution.system.domain.Treenodeinstance;

/**
 * 行为树实例节点Mapper接口
 * 
 * @author ruoyi
 * @date 2026-02-05
 */
public interface TreenodeinstanceMapper 
{
    /**
     * 查询行为树实例节点
     * 
     * @param id 行为树实例节点主键
     * @return 行为树实例节点
     */
    public Treenodeinstance selectTreenodeinstanceById(Long id);

    /**
     * 查询行为树实例节点列表
     * 
     * @param treenodeinstance 行为树实例节点
     * @return 行为树实例节点集合
     */
    public List<Treenodeinstance> selectTreenodeinstanceList(Treenodeinstance treenodeinstance);

    /**
     * 新增行为树实例节点
     * 
     * @param treenodeinstance 行为树实例节点
     * @return 结果
     */
    public int insertTreenodeinstance(Treenodeinstance treenodeinstance);

    /**
     * 修改行为树实例节点
     * 
     * @param treenodeinstance 行为树实例节点
     * @return 结果
     */
    public int updateTreenodeinstance(Treenodeinstance treenodeinstance);

    /**
     * 删除行为树实例节点
     * 
     * @param id 行为树实例节点主键
     * @return 结果
     */
    public int deleteTreenodeinstanceById(Long id);

    /**
     * 批量删除行为树实例节点
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTreenodeinstanceByIds(Long[] ids);
}
